Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(219)

Unified Diff: include/effects/SkBlurMaskFilter.h

Issue 2201993003: Add GM to test out blurmaskfilter occluders (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Clean up Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/core/SkPicture.h ('k') | src/effects/SkBlurMaskFilter.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/effects/SkBlurMaskFilter.h
diff --git a/include/effects/SkBlurMaskFilter.h b/include/effects/SkBlurMaskFilter.h
index 3ba91774f05b459f4afec83ccf09b438456b235e..89eff72290c5e5508e2da921982a8b7f63195045 100644
--- a/include/effects/SkBlurMaskFilter.h
+++ b/include/effects/SkBlurMaskFilter.h
@@ -32,13 +32,20 @@ public:
};
/** Create a blur maskfilter.
* @param style The SkBlurStyle to use
* @param sigma Standard deviation of the Gaussian blur to apply. Must be > 0.
* @param flags Flags to use - defaults to none
* @return The new blur maskfilter
*/
static sk_sp<SkMaskFilter> Make(SkBlurStyle style, SkScalar sigma,
- uint32_t flags = kNone_BlurFlag);
+ const SkRect& occluder, uint32_t flags = kNone_BlurFlag);
+
+ static sk_sp<SkMaskFilter> Make(SkBlurStyle style, SkScalar sigma,
+ uint32_t flags = kNone_BlurFlag) {
+ return Make(style, sigma, SkRect::MakeEmpty(), flags);
+ }
/** Create an emboss maskfilter
@param blurSigma standard deviation of the Gaussian blur to apply
« no previous file with comments | « include/core/SkPicture.h ('k') | src/effects/SkBlurMaskFilter.cpp » ('j') | no next file with comments »

Powered by Google App Engine
@@ -32,13 +32,20 @@ public:
};
/** Create a blur maskfilter.
- * @param style The SkBlurStyle to use
- * @param sigma Standard deviation of the Gaussian blur to apply. Must be > 0.
- * @param flags Flags to use - defaults to none
+ * @param style The SkBlurStyle to use
+ * @param sigma Standard deviation of the Gaussian blur to apply. Must be > 0.
+ * @param occluder The rect for which no pixels need be drawn (b.c. it will be overdrawn
+ * with some opaque object
+ * @param flags Flags to use - defaults to none
* @return The new blur maskfilter
*/
This is Rietveld 408576698